summaryrefslogtreecommitdiff
path: root/src/savage_cursor.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/savage_cursor.c')
-rw-r--r--src/savage_cursor.c8
1 files changed, 6 insertions, 2 deletions
diff --git a/src/savage_cursor.c b/src/savage_cursor.c
index ff0136f..be1a6c0 100644
--- a/src/savage_cursor.c
+++ b/src/savage_cursor.c
@@ -98,8 +98,12 @@ SavageHWCursorInit(ScreenPtr pScreen)
)
infoPtr->Flags |= HARDWARE_CURSOR_TRUECOLOR_AT_8BPP;
#endif
- /* With streams engine the Cursor seems to be ALWAYS TrueColor */
- infoPtr->Flags |= HARDWARE_CURSOR_TRUECOLOR_AT_8BPP;
+ /*
+ * With streams engine the Cursor seems to be ALWAYS TrueColor
+ *except at least the Savage4
+ */
+ if (psav->Chipset != S3_SAVAGE4)
+ infoPtr->Flags |= HARDWARE_CURSOR_TRUECOLOR_AT_8BPP;
infoPtr->SetCursorColors = SavageSetCursorColors;
infoPtr->SetCursorPosition = SavageSetCursorPosition;